pub struct RenderRowSpan {
cells: Vec<RenderCell>,
col: u16,
row: u16,
}Fields
cells: Vec<RenderCell>col: u16row: u16Implementations
Sourceimpl RenderRowSpan
impl RenderRowSpan
Sourcepub fn new(row: u16, col: u16, cells: Vec<RenderCell>) -> Result<Self>
pub fn new(row: u16, col: u16, cells: Vec<RenderCell>) -> Result<Self>
Build a row span with nonempty cells and valid wide-cell pairing.
Errors
- The row span has no cells.
- A wide cell is not followed by exactly one continuation cell.
pub fn cells(&self) -> &[RenderCell]
pub const fn col(&self) -> u16
pub const fn row(&self) -> u16
Sourcepub fn width(&self) -> Result<u16>
pub fn width(&self) -> Result<u16>
Return the number of terminal grid cells covered by this row span.
Errors
- The cell count does not fit in
u16.
fn validate(&self, rows: u16, cols: u16) -> Result<()>
fn validate_cells(&self) -> Result<()>
fn validate_wide_cells(&self) -> Result<()>